==> haskell-universe-reverse-instances-1.1.2-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 universe-reverse-instances
version:              1.1.2
visibility:           public
id:                   universe-reverse-instances-1.1.2-LNwd15umcR0BZRxNx0LzUu
key:                  universe-reverse-instances-1.1.2-LNwd15umcR0BZRxNx0LzUu
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  fdd97ce3bde4a94d4a66c077bbed4cc5
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.2.8/site-local/universe-reverse-instances-1.1.2

library-dirs:
    /usr/lib/ghc-9.2.8/site-local/universe-reverse-instances-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-reverse-instances
hs-libraries:         HSuniverse-reverse-instances-1.1.2-LNwd15umcR0BZRxNx0LzUu
depends:
    base-4.16.4.0 containers-0.6.5.1
    universe-base-1.1.4-9pIJO7zpNm8AwYbUHjWq0L

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-universe-reverse-instances-1.1.2-31.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-universe-reverse-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 universe-reverse-instances
version:              1.1.2
visibility:           public
id:                   universe-reverse-instances-1.1.2-DbjxXLbfXO72v9SNsJw6Xf
key:                  universe-reverse-instances-1.1.2-DbjxXLbfXO72v9SNsJw6Xf
license:              BSD-3-Clause
copyright:            Daniel Wagner 2014
maintainer:           me@dmwit.com
author:               Daniel Wagner
homepage:             https://github.com/dmwit/universe
synopsis:
    Instances of standard classes that are made possible by enumerations

description:
    For example this package provides a @Eq (a -> b)@ instance:

    @
    instance (Finite a, Eq b) => Eq (a -> b) where
    f == g = and [f x == g x | x <- universeF]
    @

category:             Data
abi:                  f80d095e346843dcf9dc1ce01da934e3
exposed:              True
exposed-modules:
    Data.Universe.Instances.Eq Data.Universe.Instances.Ord
    Data.Universe.Instances.Read Data.Universe.Instances.Show
    Data.Universe.Instances.Traversable

import-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/universe-reverse-instances-1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-universe-reverse-instances
hs-libraries:         HSuniverse-reverse-instances-1.1.2-DbjxXLbfXO72v9SNsJw6Xf
depends:
    base-4.17.2.1 containers-0.6.7
    universe-base-1.1.4-Cenxku9pKl66MlvnX9cWss

haddock-interfaces:
    /usr/share/doc/haskell-universe-reverse-instances/html/universe-reverse-instances.haddock

haddock-html:         /usr/share/doc/haskell-universe-reverse-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
